@@ -81,6 +81,7 @@ from __future__ import print_function, division, absolute_import
 import sys
 import ast
 import ctypes
+import warnings
 
 if __debug__:
     import pprint
@@ -109,7 +110,7 @@ from numba.external import pyapi
 
 def get_funcname(py_func):
     if py_func in (abs, np.abs):
-        return 'fabs'
+        return 'abs'
     elif py_func is np.round:
         return 'round'
 
@@ -117,8 +118,7 @@ def get_funcname(py_func):
 
 def resolve_pow(env, restype, args):
     promote = env.crnt.typesystem.promote
-    have_mod = len(args) == 3
-    if restype.is_numeric and not have_mod:
+    if restype.is_numeric:
         type = reduce(promote, [double, restype] + [a.type for a in args])
         signature = type(*[type] * len(args))
         result = nodes.MathCallNode(signature, args, None, name='pow')
@@ -126,12 +126,12 @@ def resolve_pow(env, restype, args):
         result = nodes.call_pyfunc(pow, args)
     return nodes.CoercionNode(result, restype)
 
-def math_call(name, args, dst_type):
+def math_call(env, name, args, dst_type):
     signature = dst_type(*[a.type for a in args])
     return nodes.MathCallNode(signature, args, None, name=name)
 
-def math_call2(name, call_node):
-    return math_call(name, [call_node.args[0]], call_node.type)
+def math_call2(env, name, call_node):
+    return math_call(env, name, [call_node.args[0]], call_node.type)
 
 # ______________________________________________________________________
 
@@ -142,6 +142,9 @@ class BuiltinResolver(object):
 
     def __init__(self, env):
         self.env = env
+        self.external_call = partial(function_util.external_call,
+                                     self.env.context,
+                                     self.env.crnt.llvm_module)
 
     def resolve_builtin_call(self, node, func):
         """
@@ -179,7 +182,7 @@ class BuiltinResolver(object):
         elif not node.type.is_numeric:
             result = nodes.call_pyfunc(func, node.args)
         else:
-            return math_call2('abs', node)
+            return math_call2(self.env, 'abs', node)
 
     def _resolve_round(self, func, node, argtype):
         return nodes.call_pyfunc(round, node.args)
@@ -194,11 +197,7 @@ class BuiltinResolver(object):
         if arg1.variable.type.is_string:
             return nodes.CoercionNode(
                 nodes.ObjectTempNode(
-                    function_util.external_call(
-                        self.env.context,
-                        self.env.crnt.llvm_module,
-                        ext_name,
-                        args=[arg1, nodes.NULL, arg2])),
+                    self.external_call(ext_name, args=[arg1, nodes.NULL, arg2])),
                 dst_type=dst_type)
 
     def _resolve_int(self, func, node, argtype, dst_type=int_):
@@ -209,6 +208,11 @@ class BuiltinResolver(object):
     def _resolve_long(self, func, node, argtype, dst_type=int_):
         return self._resolve_int_number(func, node, argtype, long_, 'PyLong_FromString')
 
+    def _resolve_len(self, func, node, argtype):
+        if argtype.is_string:
+            call = self.external_call('strlen', node.args)
+            return call # nodes.CoercionNode(call, Py_ssize_t)
+
 class ResolveCoercions(visitors.NumbaTransformer):
 
     def visit_CoercionNode(self, node):
@@ -226,6 +230,9 @@ class ResolveCoercions(visitors.NumbaTransformer):
         # TODO: the below is a problem due to implicit string <-> int coercions!
         if (node_type.is_string and dst_type.is_numeric and not
             (node_type.is_pointer or node_type.is_null)):
+            if dst_type.typename in ('char', 'uchar'):
+                raise error.NumbaError(
+                    node, "Conversion from string to (u)char not yet supported")
             result = self.str_to_int(dst_type, node)
         elif self.nopython and (is_obj(node_type) ^ is_obj(dst_type)):
             raise error.NumbaError(node, "Cannot coerce to or from object in "
@@ -293,15 +300,12 @@ class ResolveCoercions(visitors.NumbaTransformer):
         result = self.visit(node)
         return result
 
-    def _get_int_conversion_func(self, type, funcs_dict):
-        type = promote_to_native(type)
-        if type.itemsize <= long_.itemsize:
-            types = [ulong, long_]
-        else:
-            assert type.itemsize > long_.itemsize
-            types = [ulonglong, longlong]
-
-        return funcs_dict[types[type.signed]]
+    def convert_int_to_object(self, arg):
+        funcs = ["__Numba_PyInt_FromLongLong",
+                 "__Numba_PyInt_FromUnsignedLongLong"]
+        func = funcs[arg.type.signed]
+        return function_util.utility_call(self.context, self.llvm_module,
+                                          func, [arg])
 
     def visit_CoerceToObject(self, node):
         new_node = node
@@ -312,12 +316,11 @@ class ResolveCoercions(visitors.NumbaTransformer):
                                                    self.llvm_module,
                                                    "PyBool_FromLong",
                                                    args=[node.node])
-        elif node_type.is_numeric:
+        elif node_type.is_numeric and node_type.typename not in ('char', 'uchar'):
             cls = None
             args = node.node,
             if node_type.is_int:
-                cls = self._get_int_conversion_func(node_type,
-                                                    pyapi._from_long)
+                new_node = self.convert_int_to_object(node.node)
             elif node_type.is_float:
                 cls = pyapi.PyFloat_FromDouble
             elif node_type.is_complex:
@@ -447,7 +450,8 @@ class ResolveCoercions(visitors.NumbaTransformer):
         return new_node
 
 
-class LateSpecializer(ResolveCoercions, visitors.NoPythonContextMixin):
+class LateSpecializer(ResolveCoercions,
+                      visitors.NoPythonContextMixin):
 
     def visit_FunctionDef(self, node):
         self.builtin_resolver = BuiltinResolver(self.env)
@@ -613,7 +617,7 @@ class LateSpecializer(ResolveCoercions, visitors.NoPythonContextMixin):
         if self.query(node, "is_math") and node.type.is_numeric:
             assert node.func.type.is_known_value
             name = get_funcname(node.func.type.value)
-            result = math_call(name, node.args, node.type)
+            result = math_call(self.env, name, node.args, node.type)
 
         elif func_type.is_builtin:
             result = self.builtin_resolver.resolve_builtin_call_or_object(
@@ -703,6 +707,8 @@ class LateSpecializer(ResolveCoercions, visitors.NoPythonContextMixin):
         if node.type.is_object:
             return self.visit(ast.Tuple(elts=node.dims, ctx=ast.Load()))
         else:
+            if node.type.is_float:
+                self.warn(node, "Using a float for indexing")
             self.generic_visit(node)
             return node
 
